@@ -496,6 +496,13 @@ class TeslaCar:
             is not None
         )
 
+    @property
+    def pedestrian_speaker(self) -> bool:
+        """Return pedestrian warning speaker option."""
+        if "P3WS" in self._vehicle_data.get("option_codes", {}):
+            return True
+        return False
+
     @property
     def tpms_pressure_fl(self) -> float:
         """Return tire pressure sensor for front left tire."""
@@ -1269,3 +1276,15 @@ class TeslaCar:
                 "scheduled_charging_pending": enable,
             }
             self._vehicle_data["charge_state"].update(params)
+
+    async def remote_boombox(self) -> None:
+        """Remote boombox."""
+        data = await self._send_command("REMOTE_BOOMBOX")
+
+        if data and data["response"]:
+            result = data["response"]["result"]
+            reason = data["response"]["reason"]
+            if result is False:
+                _LOGGER.debug("Error calling remote boombox: %s", reason)
+            else:
+                _LOGGER.debug("Remote boombox called successfully.")
